#
# spec file for package rsgain
#
# Copyright (c) 2024 Packman Team <packman@links2linux.de>
# Copyright (c) 2023 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           rsgain
Version:        3.5.1
Release:        1699.1.pm.12
License:        BSD-2-Clause AND BSD-3-Clause
Summary:        ReplayGain 2.0 loudness normalizer
URL:            https://www.archlinux.org/packages/community/x86_64/xbmc/
Group:          System/Base
Source0:        https://github.com/complexlogic/rsgain/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  pkgconfig(fmt)
BuildRequires:  pkgconfig(inih)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libebur128)
BuildRequires:  pkgconfig(taglib)
%if 0%{?suse_version} > 1500
BuildRequires:  gcc-c++
%else
BuildRequires:  gcc13-c++
%endif

%description
A modern ReplayGain 2.0 loudness normalizer utility

%prep
%autosetup -p1

%build
export CXX=g++
test -x "$(type -p g++-13)" && export CXX=g++-13
%cmake
%cmake_build

%install
%cmake_install

%check

%files
%license LICENSE LICENSE-CRCpp
%doc CHANGELOG README.md
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/presets
%{_bindir}/rsgain
%{_datadir}/%{name}/presets/default.ini
%{_datadir}/%{name}/presets/ebur128.ini
%{_datadir}/%{name}/presets/loudgain.ini
%{_datadir}/%{name}/presets/no_album.ini

%changelog
* Mon Jun 10 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.5.1
  * Fix header gain calculation for multichannel Opus files
  * Static builds: Upgrade to FFmpeg 7
  version 3.5:
  * Add -p option to preserve file modification times
  * In Custom Mode, immediately fail if any file in the list
    does not exist or is of unsupported type
  * Fix segfault that occurs when attempting to tag corrupted
    MP4 files
  * Provide static builds for macOS and Linux
  * Unix: Include optional manpage with installation
  * Windows: Support long paths
  * Static builds: Upgrade to TagLib 2
  version 3.4:
  * Added support for Tom's lossless Audio Kompressor (TAK)
    format
  * Added -O option 'a' which sorts the output by filename
    alphanumerically
  * Added Custom Mode -o option 's' which forces Opus files to
    normalize to -23 LUFS regardless of the target loudness
    setting
  * Support files with .mp4 file extension
    + Introduce Easy Mode preset option "SkipMP4" which allows
    users to opt out of the new behavior
  * When scanning completely silent tracks, the program now
    writes "0.00 dB" and "0.000000" as gain and peak tags,
    respectively. Previously, the program would completely skip
    over these files without writing any tags to them
    + Silent tracks are not included in album gain calculations
    to keep results consistent with previous versions
  * -I 'keep' mode now default in both Custom Mode and Easy Mode
  * Fix TagMode 'n' option (regression from v3.2)
- Clean up specfile
* Mon Jul  3 2023 Philipp Seiler <p.seiler@linuxmail.org>
- removed compiler flags that didn't work for now. Will be properly fixed
  later
* Mon Jul  3 2023 Philipp Seiler <p.seiler@linuxmail.org>
- added optflags to CMake call for -fpie
* Mon Jul  3 2023 Philipp Seiler <p.seiler@linuxmail.org>
- made package compatible with Tumbleweed (added directories to file section)
* Mon Jul  3 2023 Philipp Seiler <p.seiler@linuxmail.org>
- initial commit
